redist implements methods developed by Fifield, Higgins, Imai and
Tarr (2015) to randomly sample congressional redistricting plans
using Markov Chain Monte Carlo methods. The current version of this
package implements the basic simulator and offers several
improvements to improve the performance of the algorithm and to
incorporate substantive constraints found in American congressional
redistricting. First, it allows users to draw plans that are nearly
equal in population. Second, users can apply constraints that
increase the geographic compactness of redistricting plans. Third,
it implements several tempering techniques to help efficiently
explore the full distribution of redistricting plans. Finally, it
allows users to generate standard diagnostics from the Markov Chain
Monte Carlo literature in order to examine the performacne of the
simulations. Fifield, Benjamin, Michael Higgins, Kosuke Imai and Alexander
Tarr. (2015) "A New Automated Redistricting Simulator Using Markov
Chain Monte Carlo."
Working Paper. Available at
Swendsen, Robert and Jian-Sheng Wang. (1987) "Nonuniversal Critical Dynamics in Monte Carlo Simulations." Physical Review Letters.